<?php

/*

  Maria WordPress Theme
  Author: MyPreview LTD.

 * Maria functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 */

ob_start();

/**
 * Required: set 'ot_theme_mode' filter to true.
 */
add_filter( 'ot_theme_mode', '__return_true' );

/**
 * Required: include OptionTree.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/option-tree/ot-loader.php' );

/**
 * Required: Theme Options.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-theme-options.php');

/**
 * Required: Theme Options Import & Export.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-import-export-theme-options.php');

/**
 * Required: Post Types.
 */
add_theme_support( 'post-formats', array( 'image' ) );

/**
 * Recommended: Title Tag.
 */
add_theme_support( 'title-tag' );

/**
 * Recommended: Content Width.
 */
if ( !isset( $content_width ) ):

	$content_width = 1140;

endif;

/**
 * Required: Menu.
 */
add_theme_support( 'menus' );

function register_theme_menus() {
	register_nav_menus(
			array(
				'primary_menu' => __( 'Primary Menu', 'maria' )
			)
	);
}

add_action( 'init', 'register_theme_menus' );

/**
 * Recommended: Initialize after Setup Theme.
 */
add_action( 'after_setup_theme', 'maria_theme_setup' );

function maria_theme_setup() {
	add_theme_support( 'html5', array( 'search-form' ) );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	load_theme_textdomain( 'maria', get_template_directory() . '/languages' );
}

/*
 * Required: Flush rewrite rules for custom post types.
 */
add_action( 'after_switch_theme', 'maria_flush_rewrite_rules' );

/* Flush your rewrite rules */

function maria_flush_rewrite_rules() {
	flush_rewrite_rules();
}

/**
 * Required: Enqueue theme styles.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-styles.php');

/**
 * Required: Enqueue theme JavaScript.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-js.php');

/**
 * Required: Widgets.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-widgets.php');

/**
 * Required: Search form widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-search.php');

/**
 * Required: Popular Posts widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-popular-posts.php');

/**
 * Required: Recent posts widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-recent-posts.php');

/**
 * Required: Instagram feed widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-instagram-feed.php');

/**
 * Required: Facebook Like Box widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-facebook.php');

/**
 * Required: About Me widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-about-me.php');

/**
 * Required: About Me widget.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/mw-widgets/widget-feedburner.php');

/**
 * Required: Maria Theme Filters
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-mw-filters.php');

/**
 * Required: Custom Comments.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-comments.php');

/*
 * Required: My Pagination.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-my-pagination.php');

/**
 * Required: Customize Search Results To Posts.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-search.php');

/**
 * Required: Webmaster Tools.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-webmaster-tools.php');

/**
 * Required: Extend user default social profiles.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-author-social-icons.php');

/**
 * Required: Theme Update Notification.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-update-notification.php');
