<?php

/**
 * Initialize the custom theme options.
 */
add_action( 'init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {

	/* OptionTree is not loaded yet, or this is not an admin request */
	if ( !function_exists( 'ot_settings_id' ) || !is_admin() )
		return false;

	/**
	 * Get a copy of the saved settings array. 
	 */
	$saved_settings = get_option( ot_settings_id(), array() );

	/**
	 * Custom settings array that will eventually be 
	 * passes to the OptionTree Settings API Class.
	 */
	$custom_settings = array(
		'contextual_help' => array(
			'sidebar' => ''
		),
		'sections' => array(
			array(
				'id' => 'header',
				'title' => __( 'Header', 'maria' )
			),
			array(
				'id' => 'footer',
				'title' => __( 'Footer', 'maria' )
			),
			array(
				'id' => 'favicon_settings',
				'title' => __( 'Favicon', 'maria' )
			),
			array(
				'id' => 'fonts_manager',
				'title' => __( 'Fonts Manager', 'maria' )
			),
			array(
				'id' => 'typography',
				'title' => __( 'Typography', 'maria' )
			),
			array(
				'id' => 'error_404',
				'title' => __( 'Error 404', 'maria' )
			),
			array(
				'id' => 'webmaster_tools',
				'title' => __( 'Webmaster Tools', 'maria' )
			),
			array(
				'id' => 'custom_css',
				'title' => __( 'Custom CSS', 'maria' )
			),
			array(
				'id' => 'custom_login',
				'title' => __( 'Custom Login', 'maria' )
			),
			array(
				'id' => 'advanced_options',
				'title' => __( 'Advanced Options', 'maria' )
			),
			array(
				'id' => 'theme_bundle',
				'title' => __( 'Theme Bundle', 'maria' )
			)
		),
		'settings' => array(
			array(
				'id' => 'favicon_general',
				'label' => __( 'Favicon', 'maria' ),
				'desc' => __( 'You can put url of an ico image that will represent your website\'s favicon (16px x 16px).
<br />
<em>Note: Allowed extensions are .ico, .jpg, .png and .gif</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'favicon_settings',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'apple_iphone_icon',
				'label' => __( 'Apple iPhone Icon', 'maria' ),
				'desc' => __( 'Icon for Apple iPhone (57px x 57px).
<br />
<em>Note: Allowed extensions are .ico, .jpg, .png and .gif</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'favicon_settings',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'apple_iphone_retina_icon',
				'label' => __( 'Apple iPhone Retina Icon', 'maria' ),
				'desc' => __( 'Icon for Apple iPhone Retina Version (114px x 114px).
<br />
<em>Note: Allowed extensions are .ico, .jpg, .png and .gif</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'favicon_settings',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'apple_ipad_icon',
				'label' => __( 'Apple iPad Icon', 'maria' ),
				'desc' => __( 'Icon for Apple iPhone (72px x 72px).
<br />
<em>Note: Allowed extensions are .ico, .jpg, .png and .gif</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'favicon_settings',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'apple_ipad_retina_icon',
				'label' => __( 'Apple iPad Retina Icon', 'maria' ),
				'desc' => __( 'Icon for Apple iPad Retina Version (144px x 144px).
<br />
<em>Note: Allowed extensions are .ico, .jpg, .png and .gif</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'favicon_settings',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_background_tab',
				'label' => __( 'Background', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_background',
				'label' => __( 'Background', 'maria' ),
				'desc' => __( 'If you would like to use your own custom image click the Upload (+) Image button.<br />
<em>Recommended Size is: 1920 x 261 (px)</em>', 'maria' ),
				'std' => '',
				'type' => 'background',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_social_icons_tab',
				'label' => __( 'Social icons', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_social_links',
				'label' => __( 'Social links', 'maria' ),
				'desc' => __( 'Create and organize your social links', 'maria' ),
				'std' => '',
				'type' => 'list-item',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and',
				'settings' => array(
					array(
						'id' => 'header_social_icon',
						'label' => __( 'Icon name', 'maria' ),
						'desc' => __( 'Font Awesome icon names [<a href="http://fortawesome.github.io/Font-Awesome/icons/" target="_blank"><strong>View all</strong>]</a>', 'maria' ),
						'std' => 'fa-',
						'type' => 'text',
						'rows' => '',
						'post_type' => '',
						'taxonomy' => '',
						'min_max_step' => '',
						'class' => '',
						'condition' => '',
						'operator' => 'and'
					),
					array(
						'id' => 'header_social_link',
						'label' => __( 'Link', 'maria' ),
						'desc' => __( 'Enter the full url for your icon button', 'maria' ),
						'std' => 'http://',
						'type' => 'text',
						'rows' => '',
						'post_type' => '',
						'taxonomy' => '',
						'min_max_step' => '',
						'class' => '',
						'condition' => '',
						'operator' => 'and'
					),
					array(
						'id' => 'header_social_target',
						'label' => __( 'Link options', 'maria' ),
						'desc' => '',
						'std' => '',
						'type' => 'checkbox',
						'rows' => '',
						'post_type' => '',
						'taxonomy' => '',
						'min_max_step' => '',
						'class' => '',
						'condition' => '',
						'operator' => 'and',
						'choices' => array(
							array(
								'value' => '_blank',
								'label' => __( 'Open in new window', 'maria' ),
								'src' => ''
							)
						)
					)
				)
			),
			array(
				'id' => 'header_logo_tab',
				'label' => __( 'Logo', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_logo_image_status',
				'label' => __( 'Display logo image ?', 'maria' ),
				'desc' => '',
				'std' => 'off',
				'type' => 'on-off',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_logo_text',
				'label' => __( 'Logo text', 'maria' ),
				'desc' => __( 'Enter your brand here.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => 'header_logo_image_status:is(off)',
				'operator' => 'and'
			),
			array(
				'id' => 'header_logo_text_typography',
				'label' => __( 'Typography', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => 'header_logo_image_status:is(off)',
				'operator' => 'and'
			),
			array(
				'id' => 'header_logo_image',
				'label' => __( 'Logo', 'maria' ),
				'desc' => __( 'If you would like to use your own custom image click the Upload (+) Image button.<br />
<em>Recommended Size is: 327 x 128 (px)</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => 'header_logo_image_status:is(on)',
				'operator' => 'and'
			),
			array(
				'id' => 'header_logo_image_alternative',
				'label' => __( 'Image alternative', 'maria' ),
				'desc' => __( 'Enter your brand here.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => 'header_logo_image_status:is(on)',
				'operator' => 'and'
			),
			array(
				'id' => 'header_slider_tab',
				'label' => __( 'Slider', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'header_slider_status',
				'label' => __( 'Display slider ?', 'maria' ),
				'desc' => '',
				'std' => 'header_no_slider',
				'type' => 'select',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and',
				'choices' => array(
					array(
						'value' => 'header_no_slider',
						'label' => __( 'No slider', 'maria' ),
						'src' => ''
					),
					array(
						'value' => 'header_latest_post_slider',
						'label' => __( 'Latest post slider', 'maria' ),
						'src' => ''
					),
					array(
						'value' => 'header_custom_post_slider',
						'label' => __( 'Custom post slider', 'maria' ),
						'src' => ''
					)
				)
			),
			array(
				'id' => 'header_latest_post_slider_limit',
				'label' => __( 'Blog posts show at most', 'maria' ),
				'desc' => '',
				'std' => '6',
				'type' => 'numeric-slider',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '6,12,1',
				'class' => '',
				'condition' => 'header_slider_status:is(header_latest_post_slider)',
				'operator' => 'and'
			),
			array(
				'id' => 'header_custom_slider_categories',
				'label' => __( 'Categories', 'maria' ),
				'desc' => __( 'Choose custom categories to display featured images in slider.', 'maria' ),
				'std' => '',
				'type' => 'category-checkbox',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => 'header_slider_status:is(header_custom_post_slider)',
				'operator' => 'and'
			),
			array(
				'id' => 'header_custom_slider_order',
				'label' => __( 'Display order', 'maria' ),
				'desc' => __( 'Displaying posts in random or latest order.', 'maria' ),
				'std' => 'header_custom_slider_order_random',
				'type' => 'radio',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => 'header_slider_status:is(header_custom_post_slider)',
				'operator' => 'and',
				'choices' => array(
					array(
						'value' => 'header_custom_slider_order_random',
						'label' => __( 'Random', 'maria' ),
						'src' => ''
					),
					array(
						'value' => 'header_custom_slider_order_desc',
						'label' => __( 'Latest', 'maria' ),
						'src' => ''
					)
				)
			),
			array(
				'id' => 'header_custom_post_slider_limit',
				'label' => __( 'Blog posts show at most', 'maria' ),
				'desc' => '',
				'std' => '6',
				'type' => 'numeric-slider',
				'section' => 'header',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '6,12,1',
				'class' => '',
				'condition' => 'header_slider_status:is(header_custom_post_slider)',
				'operator' => 'and'
			),
			array(
				'id' => 'footer_about_me_tab',
				'label' => __( 'About Me', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'footer',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'footer_about_me_title',
				'label' => __( 'Full Name', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'text',
				'section' => 'footer',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'footer_about_me_desc',
				'label' => __( 'Description', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'footer',
				'rows' => '7',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'footer_social_icons_tab',
				'label' => __( 'Social icons', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'footer',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'footer_social_links',
				'label' => __( 'Social links', 'maria' ),
				'desc' => __( 'Create and organize your social links', 'maria' ),
				'std' => '',
				'type' => 'list-item',
				'section' => 'footer',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and',
				'settings' => array(
					array(
						'id' => 'footer_social_icon',
						'label' => __( 'Icon name', 'maria' ),
						'desc' => __( 'Font Awesome icon names [<a href="http://fortawesome.github.io/Font-Awesome/icons/" target="_blank"><strong>View all</strong>]</a>', 'maria' ),
						'std' => 'fa-',
						'type' => 'text',
						'rows' => '',
						'post_type' => '',
						'taxonomy' => '',
						'min_max_step' => '',
						'class' => '',
						'condition' => '',
						'operator' => 'and'
					),
					array(
						'id' => 'footer_social_link',
						'label' => __( 'Link', 'maria' ),
						'desc' => __( 'Enter the full url for your icon button', 'maria' ),
						'std' => 'http://',
						'type' => 'text',
						'rows' => '',
						'post_type' => '',
						'taxonomy' => '',
						'min_max_step' => '',
						'class' => '',
						'condition' => '',
						'operator' => 'and'
					),
					array(
						'id' => 'footer_social_target',
						'label' => __( 'Link options', 'maria' ),
						'desc' => '',
						'std' => '',
						'type' => 'checkbox',
						'rows' => '',
						'post_type' => '',
						'taxonomy' => '',
						'min_max_step' => '',
						'class' => '',
						'condition' => '',
						'operator' => 'and',
						'choices' => array(
							array(
								'value' => '_blank',
								'label' => __( 'Open in new window', 'maria' ),
								'src' => ''
							)
						)
					)
				)
			),
			array(
				'id' => 'footer_copyright_tab',
				'label' => __( 'Copyright', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'footer',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'footer_copyright_text',
				'label' => __( 'Copyright', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'text',
				'section' => 'footer',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'google_fonts_api_key',
				'label' => __( 'Google Fonts API Key', 'maria' ),
				'desc' => __( 'It\'s recommended to enter your own Google Font API Key to make sure Google fonts will work properly and to get google fonts library updates.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'fonts_manager',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'google_fonts_collection',
				'label' => __( 'Google Fonts Collection', 'maria' ),
				'desc' => __( 'Add Google fonts that you will use on the website here. Adding too much fonts will negatively impact your page load speed. After adding the Google fonts and click on "Save Changes" button, Newly added fonts will be automatically populated on all typography options.', 'maria' ),
				'std' => '',
				'type' => 'google-fonts',
				'section' => 'fonts_manager',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'body_typography',
				'label' => __( 'Body', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'heading_typography',
				'label' => __( 'Heading', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'anchor_typography',
				'label' => __( 'Anchor', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'span_typography',
				'label' => __( 'Span', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'em_typography',
				'label' => __( 'Em / Italic', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'em_typography',
				'label' => __( 'Em / Italic', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'general_typography',
				'label' => __( 'General', 'maria' ),
				'desc' => __( 'p, li, td, input, label, textarea', 'maria' ),
				'std' => '',
				'type' => 'typography',
				'section' => 'typography',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'error_404_page_content',
				'label' => __( '404 Content', 'maria' ),
				'desc' => __( 'Enter custom text or media for 404 page content.', 'maria' ),
				'std' => '<h1 style="text-align: center;">Oh... 404</h1>
					<h3 style="text-align: center;">The page can not be found</h3>
<h5 style="text-align: center;">The page you are looking for is temporarily unavailable.</h5>',
				'type' => 'textarea',
				'section' => 'error_404',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'google_analytics_ua_code',
				'label' => __( 'Google Analytics UA Code', 'maria' ),
				'desc' => __( 'Enter your UA code.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'webmaster_tools',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'google_webmaster_tools',
				'label' => __( 'Google Webmaster Tools', 'maria' ),
				'desc' => __( 'Enter the verify meta value.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'webmaster_tools',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'bing_webmaster_tools',
				'label' => __( 'Bing Webmaster Tools', 'maria' ),
				'desc' => __( 'Enter the verify meta value.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'webmaster_tools',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'alexa_verification_id',
				'label' => __( 'Alexa Verification ID', 'maria' ),
				'desc' => __( 'Enter the verify meta value.', 'maria' ),
				'std' => '',
				'type' => 'text',
				'section' => 'webmaster_tools',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'seo_description',
				'label' => __( 'Default Meta Description', 'maria' ),
				'desc' => __( 'Will be used by default for home page and pages that don\'t have SEO description', 'maria' ),
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'webmaster_tools',
				'rows' => '7',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'seo_keywords',
				'label' => __( 'Default Meta Keywords', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'webmaster_tools',
				'rows' => '7',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'global_css',
				'label' => __( 'Global CSS', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'custom_css',
				'rows' => '5',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'tablets_css',
				'label' => __( 'Tablets CSS', 'maria' ),
				'desc' => __( 'Width from 768px to 985px', 'maria' ),
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'custom_css',
				'rows' => '5',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'wide_phones_css',
				'label' => __( 'Wide Phones CSS', 'maria' ),
				'desc' => __( 'Width from 480px to 767px', 'maria' ),
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'custom_css',
				'rows' => '5',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'phones_css',
				'label' => __( 'Phones CSS', 'maria' ),
				'desc' => __( 'Width from 320px to 479px', 'maria' ),
				'std' => '',
				'type' => 'textarea-simple',
				'section' => 'custom_css',
				'rows' => '5',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'remove_generator',
				'label' => __( 'Remove generator', 'maria' ),
				'desc' => '',
				'std' => 'off',
				'type' => 'on-off',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'remove_lost_pass_link',
				'label' => __( 'Remove the lost password link', 'maria' ),
				'desc' => '',
				'std' => 'off',
				'type' => 'on-off',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'remove_back_to_link',
				'label' => __( 'Remove the “Back to” link', 'maria' ),
				'desc' => '',
				'std' => 'off',
				'type' => 'on-off',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'wp_login_message',
				'label' => __( 'WordPress login page custom message', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'text',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'wp_login_bg',
				'label' => __( 'WordPress login page background', 'maria' ),
				'desc' => __( '<em>Note: Allowed extensions are .jpg, .png and .gif</em>', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'wp_login_logo',
				'label' => __( 'WordPress login page logo', 'maria' ),
				'desc' => __( 'The size of your logo should be no bigger than 320 x 67 pixels.', 'maria' ),
				'std' => '',
				'type' => 'upload',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'wp_login_logo_link',
				'label' => __( 'WordPress login page logo link', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'text',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'wp_login_logo_link_title',
				'label' => __( 'WordPress login page logo title', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'text',
				'section' => 'custom_login',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'general_advanced_options',
				'label' => __( 'General', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'advanced_options',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'additional_javascript_header',
				'label' => __( 'Additional Header Code', 'maria' ),
				'desc' => __( 'Any code you place here will appear in the head section of every page of your blog. This is useful when you need to add javascript or css to all pages.
<br />
<em> Use this code in the begining of your js code to prevent conflict issues. </em>
<br />
<pre>
jQuery(document).ready(function(){
   //here
});
</pre>', 'maria' ),
				'std' => '',
				'type' => 'javascript',
				'section' => 'advanced_options',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'additional_javascript_footer',
				'label' => __( 'Additional Footer Code', 'maria' ),
				'desc' => __( 'Any code you place here will appear in the head section of every page of your blog. This is useful when you need to add javascript or css to all pages.
<br />
<em> Use this code in the begining of your js code to prevent conflict issues. </em>
<br />
<pre>
jQuery(document).ready(function(){
   //here
});
</pre>', 'maria' ),
				'std' => '',
				'type' => 'javascript',
				'section' => 'advanced_options',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'dynamic_css_advanced_options',
				'label' => __( 'Dynamic CSS', 'maria' ),
				'desc' => '',
				'std' => '',
				'type' => 'tab',
				'section' => 'advanced_options',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'dynamic_css',
				'label' => __( 'Dynamic CSS', 'maria' ),
				'desc' => __( '<em>Note: DO NOT EDIT DEFAULT VALUES.</em>
<br />
<strong>Only edit if you know what to do!</strong> If you edit this without any knowledge on dynamic css it might break the theme!', 'maria' ),
				'std' => 'body {
	{{body_typography}}
}
#header {
	{{header_background}}
}
h1, h2, h3, h4, h5, h6 {
	{{heading_typography}}
}
a,
a:hover,
a:active,
a:focus,
a:visited {
	{{anchor_typography}}
}
span {
	{{span_typography}}
}
em {
	{{em_typography}}
}
p, li, td, input, label, textarea {
	{{general_typography}}
}
input[type="text"],
input[type="password"],
input[type="date"],
input[type="datetime"],
input[type="datetime-local"],
input[type="month"],
input[type="week"],
input[type="email"],
input[type="number"],
input[type="search"],
input[type="tel"],
input[type="time"],
input[type="url"],
input[type="color"],
input[type="submit"] {
	{{general_typography}}
}',
				'type' => 'css',
				'section' => 'advanced_options',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
			array(
				'id' => 'get_premium_theme_bundle',
				'label' => __( 'Theme Bundle', 'maria' ),
				'desc' => "<h3 class=\"font-alt\">What is included in the theme bundle ?</h3>
<p>The theme bundle includes all our <strong>Premium WordPress \ Woocommerce Themes and Plugins</strong> plus all new theme that we will release within <strong>one year</strong> starting from your theme purchase date. Since creating individual, <strong>high-quality themes</strong> is most important to us, we will always focus on quality instead of quantity, when releasing new themes.</p>
<p>Nevertheless we guarantee to release of <strong>at least 7 new themes within one calendar year</strong>. You will receive an email info, as soon as a new theme is available in your theme bundle.</p>
<h3 class=\"font-alt\">How often can I use the themes I purchased in the bundle ?</h3>
<p>You can use a theme on <strong>as many websites as you like</strong>. You can also use the themes for your client projects and customize the themes completely for your needs.</p>
<h3 class=\"font-alt\">Are theme updates included ?</h3>
<p>After purchasing the <strong>1 Year Membership Theme Bundle</strong> you will have access to all theme updates for <strong>1 year</strong> starting form your date of purchase.</p>
<p>After one year you can continue using your theme or the themes in the theme bundle, but you will not have access to updates any longer. Of course you can always decide to purchase a theme or the theme bundle for another year.</p>
<p>As a theme bundle user you will receive a <strong>50% discount coupon</strong> via email shortly before your bundle year ends, so you can continue having access to all theme updates and future theme releases for another year.</p>
<h3 class=\"font-alt\">How do I get noticed about available theme updates ?</h3>
<p>You can follow our Google+ and Facebook account in order to receive update notes and new change log details.</p>
<p>Also you can access to themes change log details via this link:
http://log.mypreview.net/[\"theme name\"]
Example: http://log.mypreview.net/oymyakon</p>
<p>Also when we release an update for our products admin notification will be appear in wordpress backend area</p>
<h3 class=\"font-alt\">When can I access to download links ?</h3>
<p>This bundle is available as an <strong>instant download</strong>, after completing your purchase.</p>
<h3 class=\"font-alt\">Do you provide documentation and tutorials ?</h3>
<p><strong>Yes.</strong> <strong>Theme documentation and video tutorials</strong> are publicly available on our youtube channel. For further theme support, our <strong>support forums</strong> and <strong>knowledge base</strong> are available to customers after the purchase of a theme.</p>
<h3 class=\"font-alt\">Do your themes work with child themes?</h3>
<p><strong>Yes.</strong> <strong>All of our themes are child theme compatible</strong>. You can add any style and functionality you want. It's really simple!</p>
<h3 class=\"font-alt\">How do I contact support?</h3>
<p>All support is handled via a dedicated support forum, available at <a href=\"http://support.mypreview.net\" target=\"_blank\"><strong><em>http://support.mypreview.net</em></strong></a>. Please head out there to open a ticket, in case you have any questions</p>
<p>Please understand that we can not answer questions regarding your individual theme customizations or theme enhancements.</p>
<h3 class=\"font-alt\">Is this bundle published on other marketplace ?</h3>
<p>This package <strong>exclusivly available</strong> in our official company website → (<a href=\"http://myPreview.net\">http://mypreview.net</a>).</p>
<h3 class=\"font-alt\">Can I use your Premium themes on WordPress.com ?</h3>
<p>For all themes purchased here on the MyPreview website you will need the self-hosted WordPress version. So you will need your own domain and webspace and install the free WordPress version you can download at <a href=\"http://wordpress.org\" target=\"_blank\">WordPress.org</a>.</p>
<h3 class=\"font-alt\">Is it allowed to customize a theme ?</h3>
<p>Yes, all MyPreview Themes and Plugins are published under the GNU General Public License (just like WordPress itself). You can customize our theme with no restrictions just as you like. You can find more information about the GNU free software license at <a href=\"http://www.gnu.org/licenses/gpl-2.0.html\" target=\"_blank\">GNU.org</a>.</p>
<h3 class=\"font-alt\">Can I renew my theme bundle purchase after one year ?</h3>
<p>If you want to continue having access to all <strong>MyPreview Premium Themes</strong>, theme updates and new theme releases, you can just purchase a new theme bundle after one year. You will receive a <strong>50% discount coupon</strong> via email for your second theme bundle purchase shortly before your theme bundle year ends. Your discount coupon will be valid for 30 days and can not be used in combination with other promotions.</p>",
				'std' => '',
				'type' => 'textblock',
				'section' => 'theme_bundle',
				'rows' => '',
				'post_type' => '',
				'taxonomy' => '',
				'min_max_step' => '',
				'class' => '',
				'condition' => '',
				'operator' => 'and'
			),
		)
	);

	/* allow settings to be filtered before saving */
	$custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );

	/* settings are not the same update the DB */
	if ( $saved_settings !== $custom_settings ) {
		update_option( ot_settings_id(), $custom_settings );
	}

	/* Lets OptionTree know the UI Builder is being overridden */
	global $ot_has_custom_theme_options;
	$ot_has_custom_theme_options = true;
}

/**
 * Required: Extend Maria Panel Theme Options.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/inc-extend-theme-options.php');
