<?php
/*

  Maria WordPress Theme
  Author: MyPreview LTD.

 */

add_action( 'widgets_init', 'maria_wp_about_widget_box' );

function maria_wp_about_widget_box() {
	register_widget( 'maria_wp_about_widget' );
}

class maria_wp_about_widget extends WP_Widget {

	function __construct() {
		parent::__construct(
				// Base ID of your widget
				'about_widget',
				// Widget name will appear in UI
				'Maria: ' . __( 'About Widget', 'maria' ),
				// Widget description
				array( 'description' => __( 'Write somethings about yourself.', 'maria' ), 'classname' => 'maria about_widget', 'id_base' => 'about_widget' )
		);
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		$subtitle = $instance['subtitle'];
		$img_url = $instance['img_url'];
		$bg_url = $instance['bg_url'];
		$description = $instance['description'];

		echo $before_widget;
		?>
		<div class="about-author-widget">
			<div class="about-author-widget-banner">
				<img src="<?php echo $bg_url; ?>" />
			</div><!-- End .about-author-widget-banner -->
			<div class="about-author-widget-avatar">
				<img src="<?php echo $img_url; ?>" />
			</div><!-- End .about-author-widget-avatar -->
			<h2 class="about-author-widget-name"><?php echo $title; ?></h2>
			<h3 class="about-author-widget-position"><em><?php echo $subtitle; ?></em></h3>
			<div class="about-author-widget-text">
				<p><?php echo $description; ?></p>
			</div><!-- End .about-author-widget-text -->
		</div><!-- End .about-author-widget -->
		<?php
		echo $after_widget;
	}

	// Widget Backend 
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['subtitle'] = strip_tags( $new_instance['subtitle'] );
		$instance['img_url'] = strip_tags( $new_instance['img_url'] );
		$instance['bg_url'] = strip_tags( $new_instance['bg_url'] );
		$instance['description'] = strip_tags( $new_instance['description'] );
		return $instance;
	}

	function form( $instance ) {
		$defaults = array( 'title' => __( 'More About Me', 'maria' ), 'subtitle' => '', 'img_url' => '', 'bg_url' => '', 'description' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'maria' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" type="text" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'subtitle' ); ?>"><?php _e( 'Subtitle:', 'maria' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'subtitle' ); ?>" name="<?php echo $this->get_field_name( 'subtitle' ); ?>" value="<?php echo esc_attr( $instance['subtitle'] ); ?>" class="widefat" type="text" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'img_url' ); ?>"><?php _e( 'Your Picture - Image Path:', 'maria' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'img_url' ); ?>" name="<?php echo $this->get_field_name( 'img_url' ); ?>" value="<?php echo esc_attr( $instance['img_url'] ); ?>" class="widefat" type="url" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'bg_url' ); ?>"><?php _e( 'Background - Image Path:', 'maria' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'bg_url' ); ?>" name="<?php echo $this->get_field_name( 'bg_url' ); ?>" value="<?php echo esc_attr( $instance['bg_url'] ); ?>" class="widefat" type="url" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php _e( 'Some Words About Yourself:', 'maria' ); ?></label>
			<textarea rows="4" class="widefat" id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" type="text"><?php echo esc_attr( $instance['description'] ); ?></textarea>
		</p>
		<?php
	}

}
